@@ -55,7 +55,7 @@ impl<K: ArrayFinite<V>, V> ArrayMap<K, V> {
 
     /// Constructs a new [`ArrayMap`] from an array of values, each corresponding to the key
     /// determined by [`Finite::nth`].
-    /// 
+    ///
     /// # Example
     /// ```
     /// use cantor::*;
@@ -125,6 +125,46 @@ impl<K: CompressFinite + ArrayFinite<V>, V> IndexMut<Compress<K>> for ArrayMap<K
     }
 }
 
+impl<K: ArrayFinite<V>, V> Clone for ArrayMap<K, V>
+where
+    K::Array: Clone,
+{
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+
+impl<K: ArrayFinite<V>, V> Copy for ArrayMap<K, V> where K::Array: Copy {}
+
+impl<K: ArrayFinite<V>, V> PartialEq for ArrayMap<K, V>
+where
+    K::Array: PartialEq,
+{
+    fn eq(&self, other: &Self) -> bool {
+        self.0 == other.0
+    }
+}
+
+impl<K: ArrayFinite<V>, V> Eq for ArrayMap<K, V> where K::Array: Eq {}
+
+impl<K: ArrayFinite<V>, V> PartialOrd for ArrayMap<K, V>
+where
+    K::Array: PartialOrd,
+{
+    fn partial_cmp(&self, other: &Self) -> Option<core::cmp::Ordering> {
+        self.0.partial_cmp(&other.0)
+    }
+}
+
+impl<K: ArrayFinite<V>, V> Ord for ArrayMap<K, V>
+where
+    K::Array: Ord,
+{
+    fn cmp(&self, other: &Self) -> core::cmp::Ordering {
+        self.0.cmp(&other.0)
+    }
+}
+
 #[test]
 fn test_map_with_key() {
     let map = ArrayMap::new(|x| if x { 1 } else { 0 });
